package com.cn.bjca.chatbots.core.pojo.callback;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * CallRecordDTO 封装了三方平台回调时通话记录的详细信息。
 * 该对象作为回调接口的输入参数，包含通话详情、客户信息、话术流程等数据。
 */
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Data
public class CallRecordDTO {

    /**
     * 回调类型，固定为 "ROBOT_CALL_RECORD"。
     * 表示该回调属于机器人通话记录类型。
     */
    private String dataType;

    /**
     * 公司ID，表示发起此次通话的公司。
     */
    private Long tenantId;

    /**
     * 任务ID，每个通话任务都会有一个唯一的标识符。
     */
    private Long robotCallJobId;

    /**
     * 任务名称，用于识别和描述该通话任务。
     */
    private String robotCallRobotName;

    /**
     * 任务创建人的手机号，用于跟踪是哪位用户创建了该任务。
     */
    private String userNumber;

    /**
     * 话术ID，用于识别此次通话使用的话术流程。
     */
    private Long dialogFlowId;

    /**
     * 线路绑定ID，表示该通话任务所使用的电话线路。
     */
    private Long tenantPhoneNumberId;

    /**
     * 通话记录ID，每次通话都会有一个唯一的记录ID，不论是否为同一客户。
     */
    private Long callRecordId;

    /**
     * 客户名称，用于记录通话涉及的客户信息。
     */
    private String customerPersonName;

    /**
     * 客户手机号，可能是加密号码或用户唯一ID（在加密或小号场景下）。
     */
    private String calledPhoneNumber;

    /**
     * 通话开始时间，格式为 yyyy-MM-dd HH:mm:ss。
     */
    private String startTime;

    /**
     * 通话结束时间，格式为 yyyy-MM-dd HH:mm:ss。
     */
    private String endTime;

    /**
     * 通话结果状态，参照枚举类型的通话结果（如：ANSWERED, NO_ANSWER等）。
     */
    private String resultStatus;

    /**
     * 通话挂断方信息，可能的值有：
     * REMOTE_HANGUP - 客户挂断；
     * INITIAL_HANGUP - AI挂断；
     * CS_HANGUP - 人工坐席挂断；
     * OTHER_HANGUP - 其他原因挂断。
     */
    private String hangupBy;

    /**
     * 用户关注点，记录在通话中客户提到的关键词，匹配到话术中的关键问答点。
     */
    private List<String> customerConcern;

    /**
     * 意向分析判断依据，记录通话中AI做出意向判断的依据。
     */
    private String analysisBasis;

    /**
     * 通话时长，以秒为单位记录通话总时长。
     */
    private Long chatDuration;

    /**
     * 通话轮次，表示客户与机器人之间的交互轮次次数。
     */
    private Long chatRound;

    /**
     * 用户属性，记录通话过程中命中话术中的流程分支。
     */
    private Set<String> attributes;

    /**
     * 自定义变量，包含话术中的动态信息以及客户属性信息。
     * 可以包含如生日、客户自定义字段等变量。
     */
    private Map<String, Object> properties;

    /**
     * 意向标签分组ID，用于表示该客户意向的标签分组。
     */
    private Long intentLevelTagId;

    /**
     * 意向标签代码，表示客户意向的级别（如1、2、3等）。
     */
    private Integer intentLevelCode;

    /**
     * 意向标签名称，描述客户意向的具体名称（如"A级意向客户"等）。
     */
    private String intentLevelDetailName;

    /**
     * 通话标签ID列表，记录命中话术规则而生成的通话标签。
     */
    private List<Long> callRecordTagIds;

    /**
     * 通话标签名称列表，描述通话中命中规则生成的标签名称。
     */
    private List<String> callRecordTagNames;

    /**
     * 客户标签ID列表，记录对客户手动打的标签及通话中生成的标签。
     */
    private List<Long> customerTagIds;

    /**
     * 客户标签名称列表，包含手动打的客户标签及通话中生成的标签。
     */
    private List<String> customerTagNames;

    /**
     * 用户和AI的合成录音地址（有效期90天），该录音包含完整的通话内容。
     */
    private String fullAudioUrl;

    /**
     * 客户录音地址（有效期90天），该录音仅包含客户的讲话内容。
     */
    private String customerAudioUrl;

    /**
     * 动态变量，通话过程中收集到的动态信息，如客户姓名、联系电话、性别等。
     */
    private Map<String, Object> dynamicProperties;

    /**
     * 通话对话详情列表，记录每一句话的内容和相关信息。
     */
    private List<CallDetailDTO> callDetailList;

    /**
     * 微信推送人ID集合，记录推送消息至微信的目标用户ID。
     */
    private Set<Long> wechatPushUsers;

    /**
     * 呼叫次数，表示同一客户多次呼叫的次数。
     */
    private Integer callCount;

    /**
     * 自动重拨次数，表示系统自动进行重拨的次数。
     */
    private Integer redialTimes;

    /**
     * 转接类型，描述通话中是否转接人工坐席。可能的值包括：
     * NO_TRANSFER - 未转接人工；
     * TRANSFERED - 已转接人工；
     * TRANSFER_CUSTOMER_FAILED - 客户未等待；
     * TRANSFER_MANUAL_FAILED - 人工未应答；
     * TRANSFER_ERROR - 转接失败。
     */
    private String transferType;

    /**
     * 转接的人工坐席号码。
     */
    private String transferPhoneNumber;

    /**
     * 号码归属地，记录客户号码的地理归属地（如：浙江杭州）。
     */
    private String location;

    /**
     * 话术名称，表示此次通话使用的话术流程的名称。
     */
    private String dialogFlowName;

    /**
     * 振铃计费时长，以分钟为单位记录振铃期间的计费时长。
     */
    private Long billRingDuration;

    /**
     * 通话计费时长，以分钟为单位记录实际通话期间的计费时长。
     */
    private Long billChatDuration;

    /**
     * 振铃时长，以秒为单位记录振铃的总时长。
     */
    private Long ringDuration;

    /**
     * 线路名称，表示此次通话所使用的线路名称。
     */
    private String phoneNumberName;

    /**
     * CallDetailDTO 内部类，记录单句对话的详细信息。
     */
    @AllArgsConstructor
    @NoArgsConstructor
    @Builder
    @Data
    public static class CallDetailDTO {

        /**
         * 对话中说的具体文字内容。
         */
        private String text;

        /**
         * 说话者，可能的值有：
         * PERSON - 表示客户；
         * ROBOT - 表示机器人。
         */
        private String type;

        /**
         * 单句对话的偏移量起始值（单位为毫秒）。
         * 用于根据录音文件截取该句对话的录音片段。
         */
        private Long startOffset;

        /**
         * 单句对话的偏移量结束值（单位为毫秒）。
         */
        private Long endOffset;

        /**
         * 对话详情ID，唯一标识单句对话的记录。
         */
        private Long callDetailId;
    }
}
